@@ -1,7 +1,7 @@
 package Proc::Find;
 
-our $DATE = '2014-12-27'; # DATE
-our $VERSION = '0.03'; # VERSION
+our $DATE = '2015-01-03'; # DATE
+our $VERSION = '0.04'; # VERSION
 
 use 5.010001;
 use strict;
@@ -199,7 +199,7 @@ Proc::Find - Find processes by name, PID, or some other attributes
 
 =head1 VERSION
 
-This document describes version 0.03 of Proc::Find (from Perl distribution Proc-Find), released on 2014-12-27.
+This document describes version 0.04 of Proc::Find (from Perl distribution Proc-Find), released on 2015-01-03.
 
 =head1 SYNOPSIS
 
@@ -341,30 +341,6 @@ C<Proc::ProcessTable>'s C<table()> method once.
  # find all processes belonging to either user
  find_any_proc([{user=>'ujang'}, {user=>'titin'}]);
 
-=head1 TODO
-
-Option to sort result.
-
-Search by PPID.
-
-Search by GID (what about additional/extra groups?).
-
-Search by priority.
-
-Search by start time.
-
-Search by memory size.
-
-Search by controlling terminal.
-
-Search all descendants of a process.
-
-Search all parent processes of a process (thus subsuming the functionality of
-and rendering L<SHARYANTO::Proc::Util> unnecessary).
-
-Write CLI utility C<pfind>, similar to C<pgrep>. Like C<pgrep>, Can also send
-signal in addition to listing processes.
-
 =head1 SEE ALSO
 
 L<Proc::Exists> can be used to check if one or more PIDs exist. If you are only
@@ -395,7 +371,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by perlancar@cpan.org.
+This software is copyright (c) 2015 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
